@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 use LWP::UserAgent;
-use HTTP::Request::Common;
+use HTTP::Request;
 use JSON;
 use URI::Escape;
 use Digest::MD5 qw(md5 md5_hex md5_base64);
@@ -45,7 +45,6 @@ sub new {
 
     $self->{'ua'} = LWP::UserAgent->new;
     $self->{'ua'}->cookie_jar( { ignore_discard => 0 } );
-    #$self->{'ua'}->cookie_jar();
     $self->{'ua'}->agent(DEFAULT_USER_AGENT);
 
     $self->{'json'} = JSON->new->allow_nonref;
@@ -72,7 +71,6 @@ sub list_downloaders {
         push @downloaders, WWW::Xunlei::Downloader->new($self, $p);
     }
 
-    #return wantarray ? @{$res->{'peerList'}} : $res->{'peerList'};
     return wantarray ? @downloaders : \@downloaders;
 }
 
@@ -109,7 +107,6 @@ sub login {
     };
 
     # $self->{'ua'}->post(join( '/', URL_LOGIN, 'sec2login/'), $parameters);
-    # $self->_debug($self->{'ua'});
     $self->_request( 'POST', URL_LOGIN . 'sec2login/', $parameters );
 }
 
@@ -219,3 +216,56 @@ sub _debug {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+WWW::Xunlei - Perl API For Official Xunlei Remote API.
+
+=head1 VERSION
+
+version 0.02
+
+=head1 SYNOPSIS
+
+    use WWW::Xunlei;
+    my $client = WWW::Xunlei->new("username", "password");
+    $client->login;
+    # use the first downloader;
+    my $downloader = $client->list_downloaders()->[0];
+    # create a remote task;
+    $downloader->create_task("http://www.cpan.org/src/5.0/perl-5.22.0.tar.gz");
+
+=head1 DESCRIPTION
+
+C<WWW::Xunlei> is a Perl Wrapper of Xunlei Remote Downloader API.
+L<Official Site of Xunlei Remote|http://yuancheng.xunlei.com>
+
+B<This module is now under deveopment. It's not stable.>
+
+=head1 METHODS
+
+=head2 new( "username", "password")
+
+=head2 login()
+
+=head2 listdownloader()
+
+=head1 AUTHOR
+
+Zhu Sheng Li <zshengli@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by Zhu Sheng Li.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
